onPaymentSheetDismissed property
A callback function that is triggered when the Apple Pay payment sheet is dismissed.
Implementation
final VoidCallback? onPaymentSheetDismissed;
A callback function that is triggered when the Apple Pay payment sheet is dismissed.
final VoidCallback? onPaymentSheetDismissed;