PEAccessToken class abstract

Interface representing an access token.

Implementers

Constructors

PEAccessToken()

Properties

accessToken → String
The access token string.
no setter
expiresIn → int
The expiration time of the token in seconds.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited