PEPaymentItem class
Represents an individual item in a payment transaction.
Each item has an associated label and amount.
Constructors
- PEPaymentItem({required double amount, required String label})
- Creates an instance of PEPaymentItem.
Properties
- amount → double
-
The monetary amount for this payment item.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
A descriptive label for this payment item (e.g., "Product A").
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this PEPaymentItem instance to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited