PEAccessTokenJson mixin
Mixin that converts a PEAccessToken to a JSON object.
- Superclass constraints
Properties
- accessToken → String
-
The access token string.
no setterinherited
- expiresIn → int
-
The expiration time of the token in seconds.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the access token details to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited